@@ -32,14 +32,14 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
-#include <libxfce4mcs/mcs-client.h>
+#include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 #include <printing-system.h>
 
 #include "print_dialog.h"
 
-#define CHANNEL         "xfprint"
+#define CHANNEL "xfprint"
 
 extern void print_dialog_run (const gchar * ifile);
 
@@ -48,7 +48,7 @@ main (int argc, char **argv)
 {
   gchar *ifile = NULL;
   gchar *decoded_ifile = NULL;
-  McsClient *client;
+  XfconfChannel *channel;
   Display *dpy;
   int screen;
   PrintingSystem *ps = NULL;
@@ -61,32 +61,26 @@ main (int argc, char **argv)
   gtk_set_locale ();
   gtk_init (&argc, &argv);
 
+  xfconf_init(NULL);
+
   /* Load the printing system module */
   dpy = GDK_DISPLAY ();
   screen = XDefaultScreen (dpy);
 
-  if (!mcs_client_check_manager (dpy, screen, "xfce-mcs-manager"))
-    g_warning ("%s: mcs manager not running\n", PACKAGE);
-  client = mcs_client_new (dpy, screen, NULL, NULL, NULL);
-  if (client) {
-    McsSetting *setting;
+  channel = xfconf_channel_new (CHANNEL);
+  if (channel) {
 
-    mcs_client_add_channel (client, CHANNEL);
-
-    if (mcs_client_get_setting (client, "XfPrint/system", CHANNEL, &setting) == MCS_SUCCESS) {
-      if (g_ascii_strcasecmp (setting->data.v_string, "none") != 0) {
-        ps = printing_system_new (setting->data.v_string);
-        if (ps == NULL)
-          g_warning ("Unable to load printing system module %s", setting->data.v_string);
+    if (xfconf_channel_has_property (channel, "/XfPrint/system")) {
+      const gchar *system_name = xfconf_channel_get_string (channel, "/XfPrint/system", "none");
+      if (g_ascii_strcasecmp (system_name, "none") != 0) {
+        ps = printing_system_new (system_name);
+        if (ps == NULL);
+          g_warning ("Unable to load printing system module %s", system_name);
       }
-      mcs_setting_free (setting);
     } else {
       g_warning ("%s: XfPrint/system is not set", PACKAGE);
     }
 
-    mcs_client_destroy (client);
-  } else {
-    g_warning ("%s: no mcs client found", PACKAGE);
   }
 
   if (ps == NULL)
@@ -171,5 +165,7 @@ main (int argc, char **argv)
   g_free (decoded_ifile);
   g_free (ifile);
 
+  xfconf_shutdown();
+
   return (EXIT_SUCCESS);
 }
